@@ -14,7 +14,7 @@ import traceback
 
 from anki.lang import _, ngettext
 from anki.utils import ids2str, fieldChecksum, stripHTML, \
-    intTime, splitFields, joinFields, maxID, json, devMode
+    intTime, splitFields, joinFields, maxID, json, devMode, stripHTMLMedia
 from anki.hooks import  runFilter, runHook
 from anki.models import ModelManager
 from anki.media import MediaManager
@@ -351,8 +351,9 @@ crt=?, mod=?, scm=?, dty=?, usn=?, ls=?, conf=?""",
         snids = ids2str(nids)
         have = {}
         dids = {}
-        for id, nid, ord, did, odid in self.db.execute(
-            "select id, nid, ord, did, odid from cards where nid in "+snids):
+        dues = {}
+        for id, nid, ord, did, due, odue, odid in self.db.execute(
+            "select id, nid, ord, did, due, odue, odid from cards where nid in "+snids):
             # existing cards
             if nid not in have:
                 have[nid] = {}
@@ -369,6 +370,11 @@ crt=?, mod=?, scm=?, dty=?, usn=?, ls=?, conf=?""",
             else:
                 # first card or multiple cards in same deck
                 dids[nid] = did
+            # save due
+            if odid != 0:
+                due = odue
+            if nid not in dues:
+                dues[nid] = due
         # build cards for each note
         data = []
         ts = maxID(self.db)
@@ -380,6 +386,7 @@ crt=?, mod=?, scm=?, dty=?, usn=?, ls=?, conf=?""",
             model = self.models.get(mid)
             avail = self.models.availOrds(model, flds)
             did = dids.get(nid) or model['did']
+            due = dues.get(nid)
             # add any missing cards
             for t in self._tmplsFromOrds(model, avail):
                 doHave = nid in have and t['ord'] in have[nid]
@@ -390,11 +397,11 @@ crt=?, mod=?, scm=?, dty=?, usn=?, ls=?, conf=?""",
                         did = 1
                     # if the deck doesn't exist, use default instead
                     did = self.decks.get(did)['id']
-                    # we'd like to use the same due# as sibling cards, but we
-                    # can't retrieve that quickly, so we give it a new id
-                    # instead
+                    # use sibling due# if there is one, else use a new id
+                    if due is None:
+                        due = self.nextID("pos")
                     data.append((ts, nid, did, t['ord'],
-                                 now, usn, self.nextID("pos")))
+                                 now, usn, due))
                     ts += 1
             # note any cards that need removing
             if nid in have:
@@ -516,7 +523,7 @@ where c.nid = n.id and c.id in %s group by nid""" % ids2str(cids)):
             if not model:
                 # note points to invalid model
                 continue
-            r.append((stripHTML(fields[self.models.sortIdx(model)]),
+            r.append((stripHTMLMedia(fields[self.models.sortIdx(model)]),
                       fieldChecksum(fields[0]),
                       nid))
         # apply, relying on calling code to bump usn+mod
@@ -831,7 +838,7 @@ select id from cards where odid > 0 and did in %s""" % ids2str(dids))
         # new cards can't have a due position > 32 bits
         self.db.execute("""
 update cards set due = 1000000, mod = ?, usn = ? where due > 1000000
-and queue = 0""", intTime(), self.usn())
+and type = 0""", intTime(), self.usn())
         # new card position
         self.conf['nextPos'] = self.db.scalar(
             "select max(due)+1 from cards where type = 0") or 0
