@@ -4,6 +4,7 @@
 
 import re
 import sre_constants
+import unicodedata
 
 from anki.utils import ids2str, splitFields, joinFields, intTime, fieldChecksum, stripHTMLMedia
 from anki.consts import *
@@ -29,6 +30,7 @@ class Finder:
             rated=self._findRated,
             tag=self._findTag,
             dupe=self._findDupes,
+            flag=self._findFlag,
         )
         self.search['is'] = self._findCardState
         runHook("search", self.search)
@@ -264,13 +266,21 @@ select distinct(n.id) from cards c, notes n where c.nid=n.id and """+preds
         elif val == "suspended":
             return "c.queue = -1"
         elif val == "buried":
-            return "c.queue = -2"
+            return "c.queue in (-2, -3)"
         elif val == "due":
             return """
 (c.queue in (2,3) and c.due <= %d) or
 (c.queue = 1 and c.due <= %d)""" % (
     self.col.sched.today, self.col.sched.dayCutoff)
 
+    def _findFlag(self, args):
+        (val, args) = args
+        if not val or val not in "01234":
+            return
+        val = int(val)
+        mask = 2**3 - 1
+        return "(c.flags & %d) == %d" % (mask, val)
+
     def _findRated(self, args):
         # days(:optional_ease)
         (val, args) = args
@@ -359,7 +369,7 @@ select distinct(n.id) from cards c, notes n where c.nid=n.id and """+preds
         ids = []
         val = val.lower()
         for m in self.col.models.all():
-            if m['name'].lower() == val:
+            if unicodedata.normalize("NFC", m['name'].lower()) == val:
                 ids.append(m['id'])
         return "n.mid in %s" % ids2str(ids)
 
@@ -385,11 +395,9 @@ select distinct(n.id) from cards c, notes n where c.nid=n.id and """+preds
         else:
             # wildcard
             ids = set()
-            # should use re.escape in the future
-            val = val.replace("*", ".*")
-            val = val.replace("+", "\\+")
+            val = re.escape(val).replace(r"\*", ".*")
             for d in self.col.decks.all():
-                if re.match("(?i)"+val, d['name']):
+                if re.match("(?i)"+val, unicodedata.normalize("NFC", d['name'])):
                     ids.update(dids(d['id']))
         if not ids:
             return
@@ -409,7 +417,7 @@ select distinct(n.id) from cards c, notes n where c.nid=n.id and """+preds
         lims = []
         for m in self.col.models.all():
             for t in m['tmpls']:
-                if t['name'].lower() == val.lower():
+                if unicodedata.normalize("NFC", t['name'].lower()) == val.lower():
                     if m['type'] == MODEL_CLOZE:
                         # if the user has asked for a cloze card, we want
                         # to give all ordinals, so we just limit to the
@@ -427,13 +435,13 @@ select distinct(n.id) from cards c, notes n where c.nid=n.id and """+preds
         mods = {}
         for m in self.col.models.all():
             for f in m['flds']:
-                if f['name'].lower() == field:
+                if unicodedata.normalize("NFC", f['name'].lower()) == field:
                     mods[str(m['id'])] = (m, f['ord'])
         if not mods:
             # nothing has that field
             return
         # gather nids
-        regex = re.escape(val).replace("\\_", ".").replace("\\%", ".*")
+        regex = re.escape(val).replace("_", ".").replace(re.escape("%"), ".*")
         nids = []
         for (id,mid,flds) in self.col.db.execute("""
 select id, mid, flds from notes
@@ -477,7 +485,7 @@ def findReplace(col, nids, src, dst, regex=False, field=None, fold=True):
     if field:
         for m in col.models.all():
             for f in m['flds']:
-                if f['name'] == field:
+                if f['name'].lower() == field.lower():
                     mmap[str(m['id'])] = f['ord']
         if not mmap:
             return 0
@@ -532,6 +540,19 @@ def fieldNames(col, downcase=True):
         return list(fields)
     return names
 
+def fieldNamesForNotes(col, nids):
+    downcasedNames = set()
+    origNames = []
+    mids = col.db.list("select distinct mid from notes where id in %s" % ids2str(nids))
+    for mid in mids:
+        model = col.models.get(mid)
+        for field in col.models.fieldNames(model):
+            if field.lower() not in downcasedNames:
+                downcasedNames.add(field.lower())
+                origNames.append(field)
+
+    return sorted(origNames, key=lambda x: x.lower())
+
 # Find duplicates
 ##########################################################################
 # returns array of ("dupestr", [nids])
