@@ -5,7 +5,7 @@
 import html
 import re, sys, threading, time, subprocess, os, atexit
 import  random
-from anki.hooks import addHook
+from anki.hooks import addHook, runHook
 from anki.utils import  tmpdir, isWin, isMac, isLin
 
 # Shared utils
@@ -88,6 +88,10 @@ from anki.mpv import MPV, MPVBase
 
 mpvPath, mpvEnv = _packagedCmd(["mpv"])
 
+def setMpvConfigBase(base):
+    global mpvEnv
+    mpvEnv['XDG_CONFIG_HOME'] = base
+
 class MpvManager(MPV):
 
     executable = mpvPath[0]
@@ -102,6 +106,8 @@ class MpvManager(MPV):
         super().__init__(window_id=None, debug=False)
 
     def queueFile(self, file):
+        runHook("mpvWillPlay", file)
+
         path = os.path.join(os.getcwd(), file)
         self.command("loadfile", path, "append-play")
 
@@ -114,6 +120,9 @@ class MpvManager(MPV):
     def seekRelative(self, secs):
         self.command("seek", secs, "relative")
 
+    def on_idle(self):
+        runHook("mpvIdleHook")
+
 mpvManager = None
 
 def setupMPV():
@@ -321,13 +330,7 @@ class PyAudioThreadedRecorder(threading.Thread):
 
         data = b""
         while not self.finish:
-            try:
-                data += stream.read(chunk)
-            except IOError as e:
-                if e[1] == pyaudio.paInputOverflowed:
-                    pass
-                else:
-                    raise
+            data += stream.read(chunk, exception_on_overflow=False)
         stream.close()
         p.terminate()
         wf = wave.open(processingSrc, 'wb')
