@@ -84,6 +84,9 @@ class DeckBrowser:
     def _renderPage(self, reuse=False):
         if not reuse:
             self._dueTree = self.mw.col.sched.deckDueTree()
+        self.web.evalWithCallback("window.pageYOffset", self.__renderPage)
+
+    def __renderPage(self, offset):
         tree = self._renderDeckTree(self._dueTree)
         stats = self._renderStats()
         self.web.stdHtml(self._body%dict(
@@ -92,12 +95,10 @@ class DeckBrowser:
                          js=["jquery.js", "jquery-ui.js", "deckbrowser.js"])
         self.web.key = "deckBrowser"
         self._drawButtons()
+        self._scrollToOffset(offset)
 
-    def _oldPos(self):
-        if self.web.key == "deckBrowser":
-            return self.web.page().mainFrame().scrollPosition()
-        else:
-            return self.scrollPos
+    def _scrollToOffset(self, offset):
+        self.web.eval("$(function() { window.scrollTo(0, %d, 'instant'); });" % offset)
 
     def _renderStats(self):
         cards, thetime = self.mw.col.db.first("""
@@ -116,9 +117,9 @@ where id > ?""", (self.mw.col.sched.dayCutoff-86400)*1000)
             return ""
         return "<br><div style='width:50%;border: 1px solid #000;padding:5px;'>"+(
             _("You have a lot of decks. Please see %(a)s. %(b)s") % dict(
-                a=("<a href=# onclick=\"pycmd('lots')\">%s</a>" % _(
+                a=("<a href=# onclick=\"return pycmd('lots')\">%s</a>" % _(
                     "this page")),
-                b=("<br><small><a href=# onclick='pycmd(\"hidelots\")'>("
+                b=("<br><small><a href=# onclick='return pycmd(\"hidelots\")'>("
                    "%s)</a></small>" % (_("hide"))+
                     "</div>")))
 
@@ -133,13 +134,14 @@ where id > ?""", (self.mw.col.sched.dayCutoff-86400)*1000)
             buf += self._topLevelDragRow()
         else:
             buf = ""
+        nameMap = self.mw.col.decks.nameMap()
         for node in nodes:
-            buf += self._deckRow(node, depth, len(nodes))
+            buf += self._deckRow(node, depth, len(nodes), nameMap)
         if depth == 0:
             buf += self._topLevelDragRow()
         return buf
 
-    def _deckRow(self, node, depth, cnt):
+    def _deckRow(self, node, depth, cnt, nameMap):
         name, did, due, lrn, new, children = node
         deck = self.mw.col.decks.get(did)
         if did == 1 and cnt > 1 and not children:
@@ -147,7 +149,7 @@ where id > ?""", (self.mw.col.sched.dayCutoff-86400)*1000)
             if not self.mw.col.db.scalar("select 1 from cards where did = 1"):
                 return ""
         # parent toggled for collapsing
-        for parent in self.mw.col.decks.parents(did):
+        for parent in self.mw.col.decks.parents(did, nameMap):
             if parent['collapsed']:
                 buff = ""
                 return buff
@@ -164,7 +166,7 @@ where id > ?""", (self.mw.col.sched.dayCutoff-86400)*1000)
         buf = "<tr class='%s' id='%d'>" % (klass, did)
         # deck link
         if children:
-            collapse = "<a class=collapse href=# onclick='pycmd(\"collapse:%d\")'>%s</a>" % (did, prefix)
+            collapse = "<a class=collapse href=# onclick='return pycmd(\"collapse:%d\")'>%s</a>" % (did, prefix)
         else:
             collapse = "<span class=collapse></span>"
         if deck['dyn']:
@@ -174,7 +176,7 @@ where id > ?""", (self.mw.col.sched.dayCutoff-86400)*1000)
         buf += """
 
         <td class=decktd colspan=5>%s%s<a class="deck %s"
-        href=# onclick="pycmd('open:%d')">%s</a></td>"""% (
+        href=# onclick="return pycmd('open:%d')">%s</a></td>"""% (
             indent(), collapse, extraclass, did, name)
         # due counts
         def nonzeroColour(cnt, colour):
@@ -187,7 +189,7 @@ where id > ?""", (self.mw.col.sched.dayCutoff-86400)*1000)
             nonzeroColour(due, "#007700"),
             nonzeroColour(new, "#000099"))
         # options
-        buf += ("<td align=center class=opts><a onclick='pycmd(\"opts:%d\");'>"
+        buf += ("<td align=center class=opts><a onclick='return pycmd(\"opts:%d\");'>"
         "<img src='/_anki/imgs/gears.svg' class=gears></a></td></tr>" % did)
         # children
         buf += self._renderDeckTree(children, depth+1)
