@@ -17,7 +17,7 @@ from aqt.qt import *
 from anki.utils import stripHTML, isWin, isMac, namedtmp, json, stripHTMLMedia, \
     checksum
 import anki.sound
-from anki.hooks import runHook, runFilter
+from anki.hooks import runHook, runFilter, addHook
 from aqt.sound import getAudio
 from aqt.webview import AnkiWebView
 from aqt.utils import shortcut, showInfo, showWarning, getFile, \
@@ -25,6 +25,7 @@ from aqt.utils import shortcut, showInfo, showWarning, getFile, \
 import aqt
 from bs4 import BeautifulSoup
 import requests
+from anki.sync import AnkiRequestsClient
 
 pics = ("jpg", "jpeg", "png", "tif", "tiff", "gif", "svg", "webp")
 audio =  ("wav", "mp3", "ogg", "flac", "mp4", "swf", "mov", "mpeg", "mkv", "m4a", "3gp", "spx", "oga", "webm")
@@ -32,9 +33,9 @@ audio =  ("wav", "mp3", "ogg", "flac", "mp4", "swf", "mov", "mpeg", "mkv", "m4a"
 _html = """
 <style>
 html { background: %s; }
-#topbuts { background: %s; }
+#topbutsOuter { background: %s; }
 </style>
-<div id="topbuts">%s</div>
+<div id="topbutsOuter"><div id="topbuts" class="clearfix">%s</div></div>
 <div id="fields"></div>
 <div id="dupes" style="display:none;"><a href="#" onclick="pycmd('dupes');return false;">%s</a></div>
 """
@@ -97,13 +98,15 @@ class Editor:
         righttopbtns = runFilter("setupEditorButtons", righttopbtns, self)
         topbuts = """
             <div id="topbutsleft" style="float:left;">
-                <button onclick="pycmd('fields')">%(flds)s...</button>
-                <button onclick="pycmd('cards')">%(cards)s...</button>
+                <button title='%(fldsTitle)s' onclick="pycmd('fields')">%(flds)s...</button>
+                <button title='%(cardsTitle)s' onclick="pycmd('cards')">%(cards)s...</button>
             </div>
             <div id="topbutsright" style="float:right;">
                 %(rightbts)s
             </div>
-        """ % dict(flds=_("Fields"), cards=_("Cards"), rightbts="".join(righttopbtns))
+        """ % dict(flds=_("Fields"), cards=_("Cards"), rightbts="".join(righttopbtns),
+                   fldsTitle=_("Customize Fields"),
+                   cardsTitle=shortcut(_("Customize Card Templates (Ctrl+L)")))
         bgcol = self.mw.app.palette().window().color().name()
         # then load page
         self.web.stdHtml(_html % (
@@ -330,7 +333,8 @@ class Editor:
                                   oncallback)
 
     def fonts(self):
-        return [(f['font'], f['size'], f['rtl'])
+        return [(runFilter("mungeEditingFontName", f['font']),
+                 f['size'], f['rtl'])
                 for f in self.note.model()['flds']]
 
     def saveNow(self, callback, keepFocus=False):
@@ -399,6 +403,7 @@ class Editor:
             warnings.simplefilter('ignore', UserWarning)
             html = str(BeautifulSoup(html, "html.parser"))
         self.note.fields[field] = html
+        self.note.flush()
         self.loadNote(focusTo=field)
 
     # Tag handling
@@ -562,8 +567,7 @@ to a cloze type first, via Edit>Change Note Type."""))
         return self.fnameToLink(fname)
 
     def _addMediaFromData(self, fname, data):
-        fname = self.mw.col.media.writeData(fname, data)
-        return self.fnameToLink(fname)
+        return self.mw.col.media.writeData(fname, data)
 
     def onRecSound(self):
         try:
@@ -582,7 +586,7 @@ to a cloze type first, via Edit>Change Note Type."""))
     def urlToLink(self, url):
         fname = self.urlToFile(url)
         if not fname:
-            return url
+            return None
         return self.fnameToLink(fname)
 
     def fnameToLink(self, fname):
@@ -610,13 +614,13 @@ to a cloze type first, via Edit>Change Note Type."""))
             or s.startswith("ftp://")
             or s.startswith("file://"))
 
-    def inlinedImageToLink(self, txt):
+    def inlinedImageToFilename(self, txt):
         prefix = "data:image/"
         suffix = ";base64,"
-        for ext in ("jpeg", "png", "gif"):
+        for ext in ("jpg", "jpeg", "png", "gif"):
             fullPrefix = prefix + ext + suffix
             if txt.startswith(fullPrefix):
-                b64data = txt[len(fullPrefix):]
+                b64data = txt[len(fullPrefix):].strip()
                 data = base64.b64decode(b64data, validate=True)
                 if ext == "jpeg":
                     ext = "jpg"
@@ -624,6 +628,13 @@ to a cloze type first, via Edit>Change Note Type."""))
 
         return ""
 
+    def inlinedImageToLink(self, src):
+        fname = self.inlinedImageToFilename(src)
+        if fname:
+            return self.fnameToLink(fname)
+
+        return ""
+
     # ext should include dot
     def _addPastedImage(self, data, ext):
         # hash and write
@@ -652,7 +663,9 @@ to a cloze type first, via Edit>Change Note Type."""))
                     'User-Agent': 'Mozilla/5.0 (compatible; Anki)'})
                 filecontents = urllib.request.urlopen(req).read()
             else:
-                r = requests.get(url, timeout=30)
+                reqs = AnkiRequestsClient()
+                reqs.timeout = 30
+                r = reqs.get(url)
                 if r.status_code != 200:
                     showWarning(_("Unexpected response code: %s") % r.status_code)
                     return
@@ -709,6 +722,9 @@ to a cloze type first, via Edit>Change Note Type."""))
                     fname = self._retrieveURL(src)
                     if fname:
                         tag['src'] = fname
+                elif src.startswith("data:image/"):
+                    # and convert inlined data
+                    tag['src'] = self.inlinedImageToFilename(src)
 
         html = str(doc)
         return html
@@ -869,7 +885,14 @@ class EditorWebView(AnkiWebView):
         html, internal = self._processHtml(mime)
         if html:
             return html, internal
-        for fn in (self._processImage, self._processUrls, self._processText):
+
+        # favour url if it's a local link
+        if mime.hasUrls() and mime.urls()[0].toString().startswith("file://"):
+            types = (self._processUrls, self._processImage, self._processText)
+        else:
+            types = (self._processImage, self._processUrls, self._processText)
+
+        for fn in types:
             html = fn(mime)
             if html:
                 return html, False
@@ -896,8 +919,16 @@ class EditorWebView(AnkiWebView):
 
         # if the user is pasting an image or sound link, convert it to local
         if self.editor.isURL(txt):
-            txt = txt.split("\r\n")[0]
-            return self.editor.urlToLink(txt)
+            url = txt.split("\r\n")[0]
+            link = self.editor.urlToLink(url)
+            if link:
+                return link
+
+            # not media; add it as a normal link if pasting with shift
+            link = '<a href="{}">{}</a>'.format(
+                url, html.escape(txt)
+            )
+            return link
 
         # normal text; convert it to HTML
         txt = html.escape(txt)
@@ -933,7 +964,9 @@ class EditorWebView(AnkiWebView):
             return
 
         data = open(path, "rb").read()
-        return self.editor._addPastedImage(data, ext)
+        fname = self.editor._addPastedImage(data, ext)
+        if fname:
+            return self.editor.fnameToLink(fname)
 
     def flagAnkiText(self):
         # be ready to adjust when clipboard event fires
@@ -960,3 +993,10 @@ class EditorWebView(AnkiWebView):
         a.triggered.connect(self.onPaste)
         runHook("EditorWebView.contextMenuEvent", self, m)
         m.popup(QCursor.pos())
+
+# QFont returns "Kozuka Gothic Pro L" but WebEngine expects "Kozuka Gothic Pro Light"
+# - there may be other cases like a trailing 'Bold' that need fixing, but will
+# wait for further reports first.
+def fontMungeHack(font):
+    return re.sub(" L$", " Light", font)
+addHook("mungeEditingFontName", fontMungeHack)
